@@ -1,6 +1,5 @@
 PostProcessChain <-
-function (coordinates = NULL, genotypes, path.mcmc, nxdom, nydom, 
-    burnin) 
+function (coordinates = NULL, path.mcmc, nxdom, nydom, burnin) 
 {
     print("Reading MCMC parameter file")
     param <- as.matrix(read.table(paste(path.mcmc, "parameters.txt", 
@@ -12,22 +11,68 @@ function (coordinates = NULL, genotypes, path.mcmc, nxdom, nydom,
         3])
     nit <- as.numeric(param[param[, 1] == "nit", 3])
     thinning <- as.numeric(param[param[, 1] == "thinning", 3])
-    ploidy <- as.numeric(param[param[, 1] == "ploidy", 3])
-    filter.null.alleles <- as.logical(param[param[, 1] == "filter.null.alleles", 
+    nindiv <- as.numeric(param[param[, 1] == "nindiv", 3])
+    use.geno2 <- as.logical(param[param[, 1] == "use.geno2", 
         3])
-    if (ploidy == 1) {
-        data.tmp <- matrix(nrow = nrow(genotypes), ncol = ncol(genotypes) * 
-            2)
-        data.tmp[, seq(1, ncol(genotypes) * 2 - 1, 2)] <- genotypes
-        data.tmp[, seq(2, ncol(genotypes) * 2, 2)] <- genotypes
-        genotypes <- data.tmp
+    use.geno1 <- as.logical(param[param[, 1] == "use.geno1", 
+        3])
+    use.qtc <- as.logical(param[param[, 1] == "use.qtc", 3])
+    use.ql <- as.logical(param[param[, 1] == "use.ql", 3])
+    spatial <- as.logical(param[param[, 1] == "spatial", 3])
+    if (nit/thinning <= burnin) {
+        print(paste("nit=", nit))
+        print(paste("thinning=", thinning))
+        print(paste("Number of saved iterations (nit/thinning) =", 
+            nit/thinning))
+        print(paste("burnin=", burnin))
+        stop("*** burnin has to be smaller than the number of saved iterations ***")
     }
+    if (use.geno2) {
+        nloc.geno2 <- as.numeric(param[param[, 1] == "nloc.geno2", 
+            3])
+        allele.numbers.geno2 <- scan(paste(path.mcmc, "allele.numbers.geno2.txt", 
+            sep = ""))
+        dominance <- param[param[, 1] == "dominance", 3]
+        filter.null.alleles <- as.logical(param[param[, 1] == 
+            "filter.null.alleles", 3])
+    }
+    else {
+        nloc.geno2 <- 1
+        allele.numbers.geno2 <- rep(-999, nloc.geno2)
+    }
+    if (use.geno1) {
+        nloc.geno1 <- as.numeric(param[param[, 1] == "nloc.geno1", 
+            3])
+        allele.numbers.geno1 <- scan(paste(path.mcmc, "allele.numbers.geno1.txt", 
+            sep = ""))
+    }
+    else {
+        nloc.geno1 <- 1
+        allele.numbers.geno1 <- rep(-999, nloc.geno1)
+    }
+    if (use.ql) {
+        nql <- as.numeric(param[param[, 1] == "nql", 3])
+        allele.numbers.ql <- scan(paste(path.mcmc, "number.levels.ql.txt", 
+            sep = ""))
+    }
+    else {
+        nql <- 1
+        allele.numbers.ql <- rep(-999, nql)
+    }
+    if (use.qtc) {
+        nqtc <- as.numeric(param[param[, 1] == "nqtc", 3])
+    }
+    else {
+        nqtc <- 1
+        qtc <- matrix(nr = nindiv, nc = nqtc, data = -999)
+    }
+    nalt <- c(allele.numbers.geno2, allele.numbers.geno1, allele.numbers.ql)
+    nalmax <- max(1, max(nalt))
     if (is.null(coordinates)) {
         if (spatial) {
             stop("Please give spatial coordinates of individuals or set argument spatial to FALSE")
         }
         else {
-            nindiv <- nrow(genotypes)
             n.int <- ceiling(sqrt(nindiv))
             x <- rep(seq(from = 0, to = 1, length = n.int), n.int)
             y <- rep(seq(from = 0, to = 1, length = n.int), n.int)
@@ -41,14 +86,6 @@ function (coordinates = NULL, genotypes, path.mcmc, nxdom, nydom,
             stop("matrix of coordinates does not have 2 columns")
     }
     coordinates <- as.matrix(coordinates)
-    data.tmp <- FormatGenotypes(as.matrix(genotypes))
-    genotypes <- data.tmp$genotypes
-    allele.numbers <- data.tmp$allele.numbers
-    if (filter.null.alleles) {
-        allele.numbers <- allele.numbers + 1
-    }
-    nindiv <- nrow(genotypes)
-    nloc <- length(allele.numbers)
     filenpop <- paste(path.mcmc, "populations.numbers.txt", sep = "")
     filenpp <- paste(path.mcmc, "nuclei.numbers.txt", sep = "")
     fileu <- paste(path.mcmc, "coord.nuclei.txt", sep = "")
@@ -58,6 +95,7 @@ function (coordinates = NULL, genotypes, path.mcmc, nxdom, nydom,
     filedom <- paste(path.mcmc, "proba.pop.membership.txt", sep = "")
     filedomperm <- paste(path.mcmc, "proba.pop.membership.perm.txt", 
         sep = "")
+    filemeanqtc <- paste(path.mcmc, "mean.qtc.txt", sep = "")
     print("Estimating number of populations")
     npop <- scan(paste(path.mcmc, "populations.numbers.txt", 
         sep = ""))
@@ -67,32 +105,39 @@ function (coordinates = NULL, genotypes, path.mcmc, nxdom, nydom,
         sep = ""))
     subK <- (npop == npop.est) & ((1:(nit/thinning)) > burnin)
     pivot <- order(lpd[subK], decreasing = TRUE)[1]
+    print(paste("Iteration with highest posterior density:", 
+        pivot))
+    ncolt <- nloc.geno2 + nloc.geno1 + nql
     dom <- matrix(nr = nxdom * nydom, nc = npopmax, data = 0)
     domperm <- matrix(nr = nxdom * nydom, nc = npopmax, data = 0)
     coorddom <- matrix(nr = 2, nc = nxdom * nydom, data = -999)
     indvois <- numeric(nxdom * nydom)
     distvois <- numeric(nxdom * nydom)
     orderf <- orderftmp <- 1:npopmax
-    nalmax <- max(allele.numbers)
     u <- matrix(nr = 2, nc = nb.nuclei.max, data = -999)
     c <- rep(times = nb.nuclei.max, -999)
     xlim <- ylim <- rep(-999, 2)
-    f <- fpiv <- array(dim = c(npopmax, nloc, nalmax), -999)
+    f <- fpiv <- array(dim = c(npopmax, ncolt, nalmax), -999)
+    meanqv <- meanqvpiv <- matrix(nr = npopmax, ncol = nqtc, 
+        -999)
     ninrub = 0
     print("Calling Fortran function postprocesschain2")
     out.res <- .Fortran(name = "postprocesschain2", PACKAGE = "Geneland", 
         as.integer(nxdom), as.integer(nydom), as.integer(burnin), 
         as.integer(ninrub), as.integer(npopmax), as.integer(nb.nuclei.max), 
-        as.integer(nindiv), as.integer(nloc), as.integer(allele.numbers), 
+        as.integer(nindiv), as.integer(nloc.geno2), as.integer(nloc.geno1), 
+        as.integer(nql), as.integer(ncolt), as.integer(nalt), 
         as.integer(nalmax), as.double(xlim), as.double(ylim), 
         as.double(delta.coord), as.integer(nit), as.integer(thinning), 
         as.character(filenpop), as.character(filenpp), as.character(fileu), 
         as.character(filec), as.character(filef), as.character(fileperm), 
-        as.character(filedom), as.double(t(coordinates)), as.double(u), 
-        as.integer(c), as.double(f), as.integer(pivot), as.double(fpiv), 
-        as.double(dom), as.double(coorddom), as.integer(indvois), 
-        as.double(distvois), as.integer(orderf), as.integer(orderftmp), 
-        as.integer(npop.est))
+        as.character(filedom), as.character(filemeanqtc), as.double(t(coordinates)), 
+        as.double(u), as.integer(c), as.double(f), as.integer(pivot), 
+        as.double(fpiv), as.double(dom), as.double(coorddom), 
+        as.integer(indvois), as.double(distvois), as.integer(orderf), 
+        as.integer(orderftmp), as.integer(npop.est), as.integer(use.geno2), 
+        as.integer(use.geno1), as.integer(use.ql), as.integer(use.qtc), 
+        as.integer(nqtc), as.double(meanqv), as.double(meanqvpiv))
     print("End of Fortran function postprocesschain2")
     coord.grid <- read.table(filedom)[, 1:2]
     pmbr <- as.matrix(read.table(filedom)[, -(1:2)])
