@@ -2,18 +2,26 @@
 {
   library.dynam("Geneland",pkg, lib)
   
+  
   cat('ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo',fill=TRUE)
   cat('o        Geneland is loaded                                       o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)
-  cat('o                * Please *                                       o',fill=TRUE)
+  cat('o        * Please *                                               o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)  
   cat('o        Register on                                              o',fill=TRUE)
-  cat('o        http://folk.uio.no/gillesg/Geneland/register.php         o',fill=TRUE)
+  cat('o        http://www2.imm.dtu.dk/~gigu/Geneland/register.php       o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)  
   cat('o        See manual on                                            o',fill=TRUE)
-  cat('o        http://folk.uio.no/gillesg/Geneland/Geneland.html        o',fill=TRUE)  
+  cat('o        http://www2.imm.dtu.dk/~gigu/Geneland/#Manual            o',fill=TRUE)  
   cat('o                                                                 o',fill=TRUE)
-  cat('o        This is Geneland-3.1.5                                   o',fill=TRUE)
+  cat('o        Type citation("Geneland") for a quick citation guide     o',fill=TRUE)
+  cat('o                                                                 o',fill=TRUE) 
+  cat('o        See http://www2.imm.dtu.dk/~gigu/Geneland/#              o',fill=TRUE)
+  cat('o        for additional references                                o',fill=TRUE)
+  cat('o                                                                 o',fill=TRUE)  
+
+  
+  cat('o        This is Geneland-3.2.1                                   o',fill=TRUE)
   cat('o                                                                 o',fill=TRUE)
   cat('ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo',fill=TRUE)
 }
